@@ -631,7 +631,7 @@ class WebDriver(webdriver.Remote):
         return self
 
     def touch_id(self, match):
-        """Do a fingerprint scan
+        """Simulate touchId on iOS Simulator
         """
         data = {
             'match': match
@@ -639,6 +639,12 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.TOUCH_ID, data)
         return self
 
+    def toggle_touch_id_enrollment(self):
+        """Toggle enroll touchId on iOS Simulator
+        """
+        self.execute(Command.TOGGLE_TOUCH_ID_ENROLLMENT)
+        return self
+
     def open_notifications(self):
         """Open notification shade in Android (API Level 18 and above)
         """
@@ -777,6 +783,15 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.KEYBOARD_INPUT, data)
         return self
 
+    # extend find element by name for backward compatibility testwa
+    def find_element_by_name(self, name):
+        body = {'using': By.ACCESSIBILITY_ID, 'value': id, 'mode': 'byName'}
+        return self.execute(SeleniumCommand.FIND_ELEMENT, body)
+
+    def find_elements_by_name(self, name):
+        body = {'using': By.ACCESSIBILITY_ID, 'value': id, 'mode': 'byName'}
+        return self.execute(SeleniumCommand.FIND_ELEMENTS, body)
+
     # add checking points testwa
     def check_element_by_accessibility_id(self, id, note=None):
         """Checks an element by accessibility id.
@@ -888,6 +903,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/device/shake')
         self.command_executor._commands[Command.TOUCH_ID] = \
             ('POST', '/session/$sessionId/appium/simulator/touch_id')
+        self.command_executor._commands[Command.TOGGLE_TOUCH_ID_ENROLLMENT] = \
+            ('POST', '/session/$sessionId/appium/simulator/toggle_touch_id_enrollment')
         self.command_executor._commands[Command.RESET] = \
             ('POST', '/session/$sessionId/appium/app/reset')
         self.command_executor._commands[Command.HIDE_KEYBOARD] = \
